@@ -3,7 +3,7 @@ package Mnet;
 # version number used by Makefile.PL
 #   these should be set to "dev", expect when creating a new release
 #   refer to developer build notes in Makefile.PL for more info
-our $VERSION = "5.10";
+our $VERSION = "5.11";
 
 =head1 NAME
 
@@ -11,15 +11,15 @@ Mnet - Testable network automation and reporting
 
 =head1 SYNOPSIS
 
-    # sample script to report Loopback0 address on cisco devices
+    # sample script to report Loopback0 ip on cisco devices
     #
     #   demonstrates typical use of all major Mnet modules
-    #   refer to perldoc for various Mnet modules for complete api info
+    #   refer to various Mnet modules for complete api info
     #
     #   use --help to list all options, or --help <option>
     #   use --device <address> to connect to device with logging
     #   use --batch <file.batch> to process multiple --device lines
-    #   add --report csv:<file.csv> to create an output csv report file
+    #   add --report csv:<file.csv> to create an output csv report
     #   add --record <file.test> to create replayable test file
     #   use --test --replay <file.test> to show script test diff
 
@@ -36,10 +36,10 @@ Mnet - Testable network automation and reporting
 
     # define --device related and --report cli options
     #   options can also be set via Mnet environment variable
+    Mnet::Opts::Cli::define({ getopt => "report=s" });
     Mnet::Opts::Cli::define({ getopt => "device=s" });
     Mnet::Opts::Cli::define({ getopt => "username=s" });
-    Mnet::Opts::Cli::define({ getopt => "password=s" });
-    Mnet::Opts::Cli::define({ getopt => "report=s" });
+    Mnet::Opts::Cli::define({ getopt => "password=s", redact => 1 });
 
     # parse cli options, also parses Mnet environment variable
     my $cli = Mnet::Opts::Cli->new;
@@ -75,6 +75,8 @@ Mnet - Testable network automation and reporting
     #   see perldoc Mnet::Expect::Cli::Ios to disable ssh host/key checks
     my $ssh = Mnet::Expect::Cli::Ios->new({
         spawn => [ "ssh", $cli->{device} ],
+        username => $cli->username,
+        password => $cli->password,
     });
 
     # retrieve config from ssh command, warn otherwise
