@@ -105,17 +105,13 @@ the L<Mnet::Log> module for more information.
     };
 
     # update future object $self hash with default opts
+    #   debug opts set here, hide internal opts w/name starting w/underscore
     foreach my $opt (sort keys %$defaults) {
         $self->{$opt} = $defaults->{$opt} if not exists $self->{$opt};
-    }
-
-    # debug output opts if creating object of this class and not internal opt
-    #   hide options that have a corresponding _option_ name with underscores
-    foreach my $opt (sort keys %$self) {
-        next if $opt =~ /^_/ or not defined $self->{$opt};
-        my $value = Mnet::Dump::line($self->{$opt});
-        $value = "****" if defined $self->{$opt} and exists $self->{"_${opt}_"};
-        $log->debug("new opts $opt = $value");
+        if ($opt !~ /^_/) {
+            my $value = Mnet::Dump::line($self->{$opt});
+            $log->debug("new opt $opt = $value");
+        }
     }
 
     # bless new object
@@ -184,17 +180,16 @@ sub spawn {
     my @spawn = ();
     @spawn = @{$self->{spawn}} if ref $self->{spawn};
     @spawn = split(/\s/, $self->{spawn}) if not ref $self->{spawn};
+    $self->debug("spawn arg: $_") foreach @spawn;
 
     # call Expect spawn method
     #   disable Mnet::Tee stdout/stderr ties if not Mnet::Tee is loaded
     #   stdout/stderr ties cause spawn problems, but can be re-enabled after
     #   init global Mnet::Expect error to undef, set on expect spawn failures
     if ($INC{'Mnet/Tee.pm'}) {
-        $self->debug("spawn calling Mnet::Tee::tie_disable");
         Mnet::Tee::tie_disable();
         $self->debug("spawn calling Expect module spawm method");
         $self->fatal("spawn error, $!") if not $self->expect->spawn(@spawn);
-        $self->debug("spawn calling Mnet::Tee::tie_enable");
         Mnet::Tee::tie_enable();
     } else {
         $self->fatal("spawn error, $!") if not $self->expect->spawn(@spawn);
